@@ -9,8 +9,8 @@
 #
 package Test::Moose::More;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.038-24-g07edb95
-$Test::Moose::More::VERSION = '0.039'; # TRIAL
+# git description: 0.039-12-gf95fd48
+$Test::Moose::More::VERSION = '0.040'; # TRIAL
 
 # ABSTRACT: More tools for testing Moose packages
 
@@ -105,8 +105,15 @@ sub does_ok ($$;$) {
     $roles     = [ $roles ] unless ref $roles;
     $message ||= _thing_name($thing, $thing_meta) . ' does %s';
 
+    # this generally happens when we're checking a vanilla attribute
+    # metaclass, which turns out to be a
+    # Class::MOP::Class::Immutable::Class::MOP::Class.  If our metaclass does
+    # not have a does_role() method, then by definition the metaclass cannot
+    # do the role (that is, it's a Class::MOP metaclass).
+    my $_does = $thing_meta->can('does_role') || sub { 0 };
+
     BEGIN { warnings::unimport 'redundant' if $^V gt v5.21.1 }
-    $tb->ok(!!$thing_meta->does_role($_), sprintf($message, $_))
+    $tb->ok(!!$thing_meta->$_does($_), sprintf($message, $_))
         for @$roles;
 
     return;
@@ -121,8 +128,10 @@ sub does_not_ok ($$;$) {
     $roles     = [ $roles ] unless ref $roles;
     $message ||= _thing_name($thing, $thing_meta) . ' does not do %s';
 
+    my $_does = $thing_meta->can('does_role') || sub { 0 };
+
     BEGIN { warnings::unimport 'redundant' if $^V gt v5.21.1 }
-    $tb->ok(!$thing_meta->does_role($_), sprintf($message, $_))
+    $tb->ok(!$thing_meta->$_does($_), sprintf($message, $_))
         for @$roles;
 
     return;
@@ -155,7 +164,7 @@ sub has_method_ok ($@) {
 
     ### $thing
     my $meta = find_meta($thing);
-    my $name = $meta->name;
+    my $name = _thing_name($thing, $meta);
 
     ### @methods
     $tb->ok(!!$meta->has_method($_), "$name has method $_")
@@ -191,7 +200,7 @@ sub requires_method_ok ($@) {
 
     ### $thing
     my $meta = find_meta($thing);
-    my $name = $meta->name;
+    my $name = _thing_name($thing, $meta);
 
     ### @methods
     $tb->ok(!!$meta->requires_method($_), "$name requires method $_")
@@ -372,7 +381,7 @@ sub _validate_class_guts {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     return unless is_class_ok $class;
 
-    my $name = ref $class || $class;
+    my $name = _thing_name($class);
     do { ok($class->isa($_), "$name isa $_") for @{$args{isa}} }
         if exists $args{isa};
 
@@ -447,6 +456,7 @@ sub _validate_attribute_guts {
     return unless has_attribute_ok($thing, $name);
     my $att = _find_attribute($thing => $name);
 
+    local $THING_NAME = _thing_name($thing) . "'s attribute $name";
     return _validate_attribute($att, %opts);
 }
 
@@ -465,8 +475,14 @@ sub __validate_attribute_guts {
         if $thing_opts{does};
 
     ### %thing_opts
-    validate_class $att => %thing_opts
-        if keys %thing_opts;
+    {
+        # If $THING_NAME is set, we're processing an attribute metaclass via
+        # _validate_attribute_guts() or _validate_thing_guts()
+        local $THING_NAME = "${THING_NAME}'s metaclass"
+            if !!$THING_NAME;
+        validate_class $att => %thing_opts
+            if keys %thing_opts;
+    }
 
     return _attribute_options_ok($att, %opts);
 }
@@ -478,7 +494,7 @@ sub attribute_options_ok ($$@) {
     return unless has_attribute_ok($thing, $name);
     my $att = _find_attribute($thing => $name);
 
-    return _attribute_options_ok($att, %opts);
+    return _validate_subtest_wrapper(\&_attribute_options_ok => ($att, %opts));
 }
 
 sub _attribute_options_ok {
@@ -614,7 +630,7 @@ Test::Moose::More - More tools for testing Moose packages
 
 =head1 VERSION
 
-This document describes version 0.039 of Test::Moose::More - released October 10, 2016 as part of Test-Moose-More.
+This document describes version 0.040 of Test::Moose::More - released November 10, 2016 as part of Test-Moose-More.
 
 =head1 SYNOPSIS
 
@@ -908,7 +924,6 @@ additional class-specific tests.
 
         attributes => [ ... ],
         methods    => [ ... ],
-        isa        => [ ... ],
 
         # ensures sugar is/is-not present
         sugar      => 0,
@@ -1006,6 +1021,14 @@ Note that some of these options will skip if used against attributes defined in
 
 =item *
 
+-subtest => 'subtest name...'
+
+If set, all tests run (save the first, "does this thing even have this
+attribute?" test) will be wrapped in a subtest, the name of which will be
+whatever C<-subtest> is set to.
+
+=item *
+
 is => ro|rw
 
 Tests for reader/writer options set as one would expect.
